# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/api/v2/cds.proto
# Protobuf Python Version: 4.25.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.api.v2 import discovery_pb2 as envoy_dot_api_dot_v2_dot_discovery__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from envoy.annotations import resource_pb2 as envoy_dot_annotations_dot_resource__pb2
from udpa.annotations import migrate_pb2 as udpa_dot_annotations_dot_migrate__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from envoy.api.v2 import cluster_pb2 as envoy_dot_api_dot_v2_dot_cluster__pb2

from envoy.api.v2.cluster_pb2 import *

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x16\x65nvoy/api/v2/cds.proto\x12\x0c\x65nvoy.api.v2\x1a\x1c\x65nvoy/api/v2/discovery.proto\x1a\x1cgoogle/api/annotations.proto\x1a envoy/annotations/resource.proto\x1a\x1eudpa/annotations/migrate.proto\x1a\x1dudpa/annotations/status.proto\x1a\x1a\x65nvoy/api/v2/cluster.proto\"\n\n\x08\x43\x64sDummy2\xe7\x02\n\x17\x43lusterDiscoveryService\x12W\n\x0eStreamClusters\x12\x1e.envoy.api.v2.DiscoveryRequest\x1a\x1f.envoy.api.v2.DiscoveryResponse\"\x00(\x01\x30\x01\x12`\n\rDeltaClusters\x12#.envoy.api.v2.DeltaDiscoveryRequest\x1a$.envoy.api.v2.DeltaDiscoveryResponse\"\x00(\x01\x30\x01\x12s\n\rFetchClusters\x12\x1e.envoy.api.v2.DiscoveryRequest\x1a\x1f.envoy.api.v2.DiscoveryResponse\"!\x82\xd3\xe4\x93\x02\x1b\"\x16/v2/discovery:clusters:\x01*\x1a\x1c\x8a\xa4\x96\xf3\x07\x16\n\x14\x65nvoy.api.v2.ClusterB\x8b\x01\n\x1aio.envoyproxy.envoy.api.v2B\x08\x43\x64sProtoP\x01Z9github.com/envoyproxy/go-control-plane/envoy/api/v2;apiv2\xf2\x98\xfe\x8f\x05\x1a\x12\x18\x65nvoy.service.cluster.v3\xba\x80\xc8\xd1\x06\x02\x10\x01P\x05\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.api.v2.cds_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\032io.envoyproxy.envoy.api.v2B\010CdsProtoP\001Z9github.com/envoyproxy/go-control-plane/envoy/api/v2;apiv2\362\230\376\217\005\032\022\030envoy.service.cluster.v3\272\200\310\321\006\002\020\001'
  _globals['_CLUSTERDISCOVERYSERVICE']._options = None
  _globals['_CLUSTERDISCOVERYSERVICE']._serialized_options = b'\212\244\226\363\007\026\n\024envoy.api.v2.Cluster'
  _globals['_CLUSTERDISCOVERYSERVICE'].methods_by_name['FetchClusters']._options = None
  _globals['_CLUSTERDISCOVERYSERVICE'].methods_by_name['FetchClusters']._serialized_options = b'\202\323\344\223\002\033\"\026/v2/discovery:clusters:\001*'
  _globals['_CDSDUMMY']._serialized_start=225
  _globals['_CDSDUMMY']._serialized_end=235
  _globals['_CLUSTERDISCOVERYSERVICE']._serialized_start=238
  _globals['_CLUSTERDISCOVERYSERVICE']._serialized_end=597
# @@protoc_insertion_point(module_scope)
