# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/network/dns_resolver/getaddrinfo/v3/getaddrinfo_dns_resolver.proto
# Protobuf Python Version: 4.25.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nSenvoy/extensions/network/dns_resolver/getaddrinfo/v3/getaddrinfo_dns_resolver.proto\x12\x34\x65nvoy.extensions.network.dns_resolver.getaddrinfo.v3\x1a\x1dudpa/annotations/status.proto\"\x1e\n\x1cGetAddrInfoDnsResolverConfigB\xd6\x01\nBio.envoyproxy.envoy.extensions.network.dns_resolver.getaddrinfo.v3B\x1bGetaddrinfoDnsResolverProtoP\x01Zigithub.com/envoyproxy/go-control-plane/envoy/extensions/network/dns_resolver/getaddrinfo/v3;getaddrinfov3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.extensions.network.dns_resolver.getaddrinfo.v3.getaddrinfo_dns_resolver_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\nBio.envoyproxy.envoy.extensions.network.dns_resolver.getaddrinfo.v3B\033GetaddrinfoDnsResolverProtoP\001Zigithub.com/envoyproxy/go-control-plane/envoy/extensions/network/dns_resolver/getaddrinfo/v3;getaddrinfov3\272\200\310\321\006\002\020\002'
  _globals['_GETADDRINFODNSRESOLVERCONFIG']._serialized_start=172
  _globals['_GETADDRINFODNSRESOLVERCONFIG']._serialized_end=202
# @@protoc_insertion_point(module_scope)
