# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/config/filter/dubbo/router/v2alpha1/router.proto
# Protobuf Python Version: 4.25.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from udpa.annotations import migrate_pb2 as udpa_dot_annotations_dot_migrate__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n6envoy/config/filter/dubbo/router/v2alpha1/router.proto\x12)envoy.config.filter.dubbo.router.v2alpha1\x1a\x1eudpa/annotations/migrate.proto\x1a\x1dudpa/annotations/status.proto\"\x08\n\x06RouterB\xe0\x01\n7io.envoyproxy.envoy.config.filter.dubbo.router.v2alpha1B\x0bRouterProtoP\x01ZPgithub.com/envoyproxy/go-control-plane/envoy/config/filter/dubbo/router/v2alpha1\xf2\x98\xfe\x8f\x05\x38\x12\x36\x65nvoy.extensions.filters.network.dubbo_proxy.router.v3\xba\x80\xc8\xd1\x06\x02\x10\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.config.filter.dubbo.router.v2alpha1.router_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n7io.envoyproxy.envoy.config.filter.dubbo.router.v2alpha1B\013RouterProtoP\001ZPgithub.com/envoyproxy/go-control-plane/envoy/config/filter/dubbo/router/v2alpha1\362\230\376\217\0058\0226envoy.extensions.filters.network.dubbo_proxy.router.v3\272\200\310\321\006\002\020\001'
  _globals['_ROUTER']._serialized_start=164
  _globals['_ROUTER']._serialized_end=172
# @@protoc_insertion_point(module_scope)
