# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/load_balancing_policies/cluster_provided/v3/cluster_provided.proto
# Protobuf Python Version: 4.25.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nSenvoy/extensions/load_balancing_policies/cluster_provided/v3/cluster_provided.proto\x12<envoy.extensions.load_balancing_policies.cluster_provided.v3\x1a\x1dudpa/annotations/status.proto\"\x11\n\x0f\x43lusterProvidedB\xe4\x01\nJio.envoyproxy.envoy.extensions.load_balancing_policies.cluster_provided.v3B\x14\x43lusterProvidedProtoP\x01Zvgithub.com/envoyproxy/go-control-plane/envoy/extensions/load_balancing_policies/cluster_provided/v3;cluster_providedv3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.extensions.load_balancing_policies.cluster_provided.v3.cluster_provided_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\nJio.envoyproxy.envoy.extensions.load_balancing_policies.cluster_provided.v3B\024ClusterProvidedProtoP\001Zvgithub.com/envoyproxy/go-control-plane/envoy/extensions/load_balancing_policies/cluster_provided/v3;cluster_providedv3\272\200\310\321\006\002\020\002'
  _globals['_CLUSTERPROVIDED']._serialized_start=180
  _globals['_CLUSTERPROVIDED']._serialized_end=197
# @@protoc_insertion_point(module_scope)
